@@ -7,7 +7,7 @@ repositories {
 }
 
 dependencies {
-    testCompile("junit:junit:4.12")
+    testImplementation("junit:junit:4.12")
 }
 
 // tag::test-categories[]
